@@ -1,5 +1,4 @@
 import tkinter as tk
-from cProfile import label
 
 import cv2
 import matplotlib.pyplot as plt
@@ -7,19 +6,23 @@ import numpy as np
 from matplotlib.backends.backend_agg import FigureCanvasAgg
 from matplotlib.figure import Figure
 from matplotlib.ticker import AutoMinorLocator
+from mpl_toolkits.axes_grid1.inset_locator import inset_axes, mark_inset
 from PIL import Image, ImageTk
 from win32api import GetSystemMetrics
 
 from ..resources.language import Text
-from .datatypes import Measurement, Simulation
+from .measurement_import import Measurement
+from .ptw_import import PTWMultimporter
+from .sim_import import Simulation
 
 
 class DoseFigureHandler:
-    def __init__(self, parent, norm=True):
+    def __init__(self, parent, norm, zoom):
 
         self.parent = parent
 
         self.norm = norm
+        self.zoom = zoom
 
         # Initialize the current settings
         self.lang = self.parent.lang
@@ -27,14 +30,14 @@ class DoseFigureHandler:
         self.style = plt.style.use("default")
         self.current_mode = self.parent.dark.get()
         self.colors = {
-            False: ["green", "blue", "red", "cyan", "magenta"],
+            False: ["#ff2e1b", "#ffa43c", "#1bff67", "#ff5cf1", "#493cff"],
             True: ["#ff7fff", "#ffff00", "#00ffff", "#ff4040", "#40ff40"],
         }
-        self.marker = "o-."
+        self.marker = "o--"
         self.markersize = self.parent.profile.get_attribute("markersize")
         self.linewidth = self.parent.profile.get_attribute("linewidth")
         # Initialize the figure and axes
-        self.fig = Figure(figsize=(10, 5), constrained_layout=True, dpi=600)
+        self.fig = Figure(figsize=(10, 5), constrained_layout=True, dpi=1200)
         self.canvas = FigureCanvasAgg(self.fig)
         self.ax = self.fig.add_subplot(111)
 
@@ -121,6 +124,13 @@ class DoseFigureHandler:
             if filename not in [plotdata.filepath for plotdata in self.plots]:
                 if type == "simulation":
                     self.plots += [Simulation(filename)]
+                elif type == "ptw":
+                    importer = PTWMultimporter(filename, self.parent.parent)
+                    importer.window.mainloop()
+                    self.plots += [plot for plot in importer.plots]
+                    importer.window.destroy()
+                    del importer
+
                 else:
                     self.plots += [Measurement(filename, type)]
 
@@ -171,8 +181,15 @@ class DoseFigureHandler:
             if len(plot_data) == 7:
                 Q, dQ, zmax = plot_data[4], plot_data[5], plot_data[6]
                 textstr = "Q     = {} ± {}\n{} = {} mm".format(Q, dQ, "$z_{max}$", zmax)
+                space = 0
+                if dQ == 0:
+                    space = 0.05
+                if len(str(Q)) == 6:
+                    space += 0.01
+                if len(str(dQ)) == 6:
+                    space += 0.01
                 self.ax.text(
-                    0.795,
+                    0.795 + space,
                     0.7 - 0.1 * index,
                     textstr,
                     transform=self.ax.transAxes,
@@ -225,7 +242,7 @@ class DoseFigureHandler:
                 )
 
                 self.ax.text(
-                    0.105 + 0.21 * index,
+                    (0.6 - 0.1 * len(self.data)) + 0.2 * index,
                     0.5,
                     textstr,
                     transform=self.ax.transAxes,
@@ -243,6 +260,8 @@ class DoseFigureHandler:
         """
         xlabel = "{}-{} [mm]".format(self.data[0][1], self.text.axis[self.lang])
         self.ax.set_xlabel(xlabel, size=12)
+        if self.norm == False:
+            self.ax.set_ylabel(self.plots[0].unit, size=12)
 
     def create_plots_from_data(self):
 
@@ -272,6 +291,67 @@ class DoseFigureHandler:
                 label=f"{self.plots[index].filename}",
             )
 
+        if self.zoom == False:
+            try:
+                self.axins.remove()
+            except:
+                pass
+
+        if self.zoom == True:
+            try:
+                self.axins.remove()
+            except:
+                pass
+
+            self.axins = inset_axes(self.ax, "28%", "28%", loc="lower left")
+            yvalsat195 = []
+            yvalsat205 = []
+            for index, plot_data in enumerate(self.data):
+                self.axins.errorbar(
+                    x=plot_data[0],
+                    y=plot_data[2],
+                    yerr=plot_data[3],
+                    fmt="none",
+                    ecolor="r",
+                    elinewidth=0.5,
+                    capsize=1,
+                    capthick=0.2,
+                    ms=2,
+                )
+                self.axins.plot(
+                    plot_data[0],
+                    plot_data[2],
+                    self.marker,
+                    markersize=self.markersize,
+                    color=self.colors[self.current_mode][index],
+                    linewidth=self.linewidth,
+                    label=f"{self.plots[index].filename}",
+                )
+                yvalsat195 += [
+                    plot_data[2][
+                        plot_data[0].index(
+                            min(plot_data[0], key=lambda x: abs(x - 195))
+                        )
+                    ]
+                ]
+                yvalsat205 += [
+                    plot_data[2][
+                        plot_data[0].index(
+                            min(plot_data[0], key=lambda x: abs(x - 205))
+                        )
+                    ]
+                ]
+
+            # sub region of the original image
+            x1, x2, y1, y2 = (195, 205, min(yvalsat205), max(yvalsat195))
+            self.axins.set_xlim(x1, x2)
+            self.axins.set_ylim(y1, y2)
+            self.axins.tick_params(
+                labelleft=False, labelbottom=False, bottom=False, left=False
+            )
+
+            mark_inset(self.ax, self.axins, loc1=2, loc2=4, fc="none", ec="0.5")
+
     def return_figure(self, filenames):
 
         """
