@@ -2,6 +2,8 @@ import os
 import tkinter as tk
 import tkinter.ttk as ttk
 from tkinter import filedialog as fd
+from tkinter import simpledialog as sd
+from tkinter.font import NORMAL
 
 from PIL import Image, ImageTk
 
@@ -20,14 +22,23 @@ class MainApplication(tk.Frame):
         # Read settings from profile.json and initialize the necessary variables
         self.profile = ProfileHandler()
         self.lang = self.profile.get_attribute("language")
+
         self.langvar = tk.StringVar()
         self.langvar.set(self.lang)
         self.text = Text()
+
         self.dark = tk.BooleanVar()
         self.dark.set(False)
+
         self.norm = tk.BooleanVar()
         self.norm.set(bool(self.profile.get_attribute("normalize")))
-        self.DoseFigureHandler = DoseFigureHandler(self, self.norm.get())
+
+        self.zoom = tk.BooleanVar()
+        self.zoom.set(bool(self.profile.get_attribute("zoom")))
+
+        self.DoseFigureHandler = DoseFigureHandler(
+            self, self.norm.get(), self.zoom.get()
+        )
 
         self.parent.title(self.text.window_title[self.lang])
         style = ttk.Style(self.parent)
@@ -51,6 +62,7 @@ class MainApplication(tk.Frame):
         self.parent.bind("<Control-o>", self.o_key)
         self.parent.bind("<Control-s>", self.s_key)
         self.parent.bind("<Control-t>", self.t_key)
+        self.parent.bind("<Control-p>", self.p_key)
         self.parent.bind("<Escape>", self.esc_key)
         self.parent.bind("<Control-z>", self.z_key)
 
@@ -68,6 +80,12 @@ class MainApplication(tk.Frame):
             command=lambda: self.load_file("dp"),
             accelerator="Ctrl+D",
         )
+        self.addmeasuremenu.add_command(
+            label=self.text.ptw[self.lang],
+            command=lambda: self.load_file("ptw"),
+            accelerator="Ctrl+P",
+        )
+
         self.filemenu.add_command(
             label=self.text.loadsim[self.lang],
             command=lambda: self.load_file("simulation"),
@@ -159,9 +177,12 @@ class MainApplication(tk.Frame):
         self.normmenu = tk.Menu(self.menubar)
         self.normmenu.add_checkbutton(
             label=self.text.normalize[self.lang],
-            command=lambda: self.normalize(self.norm.get()),
+            command=self.normalize,
             variable=self.norm,
         )
+        self.normmenu.add_checkbutton(
+            label=self.text.zoom[self.lang], command=self.zoomgraph, variable=self.zoom,
+        )
         self.normmenu.add_separator()
         self.markersizemenu = tk.Menu(self.menubar)
         self.markersizemenu.add_command(
@@ -208,6 +229,7 @@ class MainApplication(tk.Frame):
         self.canvas.image = None
         self.current_file = None
         self.filenames = []
+        self.rename_boxes = []
 
         self.parent.geometry(geometry)
         self.pack(side="top", fill="both", expand=True)
@@ -270,7 +292,7 @@ class MainApplication(tk.Frame):
         self.__init__(self.parent, geometry)
         return
 
-    def normalize(self, norm):
+    def normalize(self):
 
         self.DoseFigureHandler.norm = self.norm.get()
 
@@ -282,6 +304,17 @@ class MainApplication(tk.Frame):
             self.show_preview()
         return
 
+    def zoomgraph(self):
+        self.DoseFigureHandler.zoom = self.zoom.get()
+
+        self.profile.set_attribute("zoom", int(self.zoom.get()))
+
+        if self.filenames != []:
+            self.canvas.itemconfig(self.image_on_canvas, image=None)
+            self.DoseFigureHandler.flush()
+            self.show_preview()
+        return
+
     def change_marker_size(self, boolean):
         if boolean == True:
             self.DoseFigureHandler.markersize += 0.2
@@ -323,17 +356,20 @@ class MainApplication(tk.Frame):
 
         if type == "simulation":
             filetypes = [(self.text.simulationdata[self.lang], ".csv")]
-        else:
+        elif type == "pdd" or type == "dp":
             filetypes = [(self.text.measurementdata[self.lang], ["txt", ".csv"])]
+        elif type == "ptw":
+            filetypes = [(self.text.ptw[self.lang], ".mcc")]
 
-        self.current_file = fd.askopenfilename(
+        self.current_file = fd.askopenfilenames(
             initialdir=os.getcwd(), filetypes=filetypes
         )
 
         if self.current_file == "":
             return
 
-        self.filenames += [(self.current_file, type)]
+        for file in self.current_file:
+            self.filenames += [(file, type)]
 
         self.show_preview()
         self.filemenu.entryconfig(0, state=tk.DISABLED)
@@ -352,6 +388,8 @@ class MainApplication(tk.Frame):
         self.filemenu.entryconfig(1, state=tk.NORMAL)
         self.filemenu.entryconfig(3, state=tk.DISABLED)
         self.filemenu.entryconfig(4, state=tk.DISABLED)
+        self.addmenu.entryconfig(0, state=tk.NORMAL)
+        self.addmenu.entryconfig(1, state=tk.NORMAL)
         self.addmeasuremenu.entryconfig(0, state=tk.NORMAL)
         self.addmeasuremenu.entryconfig(1, state=tk.NORMAL)
         self.menubar.delete(3, 4)
@@ -367,17 +405,25 @@ class MainApplication(tk.Frame):
         Removes the graph added last
         """
 
-        self.filenames.pop(-1)
-        if len(self.filenames) < 2:
-            self.addmenu.entryconfig(3, state=tk.DISABLED)
+        if len(self.filenames) == 1:
+            self.close_file()
+            return
+
+        if self.filenames[-1][0].endswith(".mcc") == True:
+            self.filenames.pop(-1)
+            while len(self.filenames) < len(self.DoseFigureHandler.plots):
+                self.DoseFigureHandler.plots.pop(-1)
+
+        else:
+            self.filenames.pop(-1)
+            self.DoseFigureHandler.plots.pop(-1)
 
         if len(self.filenames) <= 4:
             self.addmenu.entryconfig(0, state=tk.NORMAL)
             self.addmenu.entryconfig(1, state=tk.NORMAL)
 
-        self.canvas.itemconfig(self.image_on_canvas, image=None)
         self.DoseFigureHandler.flush()
-        self.DoseFigureHandler.plots.pop(-1)
+        self.canvas.itemconfig(self.image_on_canvas, image=None)
         self.show_preview()
 
     def save_graph(self):
@@ -408,12 +454,14 @@ class MainApplication(tk.Frame):
         self.canvas.pack_forget()
         self.canvas = tk.Canvas(self)
         self.canvas.bind("<Configure>", self.handle_configure)
-        self.canvas.pack(fill="both", expand=True)
+        self.canvas.bind("<Button-1>", self.check_click)
+        self.canvas.bind("<Motion>", self.check_hand)
+        self.canvas.pack(side=tk.TOP, fill="both", expand=True)
 
-        if len(self.filenames) >= 2:
+        if len(self.DoseFigureHandler.plots) >= 2:
             self.addmenu.entryconfig(3, state=tk.NORMAL)
 
-        if len(self.filenames) == 5:
+        if len(self.DoseFigureHandler.plots) == 5:
             self.addmenu.entryconfig(0, state=tk.DISABLED)
             self.addmenu.entryconfig(1, state=tk.DISABLED)
 
@@ -433,10 +481,33 @@ class MainApplication(tk.Frame):
         self.canvas.image = self.photoimage
         self.canvas.itemconfig(self.image_on_canvas, image=self.canvas.image)
 
+        for i in range(len(self.DoseFigureHandler.plots)):
+            temp = self.canvas.create_rectangle(
+                (
+                    -0.00833
+                    * max(
+                        map(
+                            len,
+                            [plot.filename for plot in self.DoseFigureHandler.plots],
+                        )
+                    )
+                    + 0.94633
+                )
+                * self.canvas.image.width(),
+                (0.023 + 0.042 * i) * self.canvas.image.height(),
+                0.988 * self.canvas.image.width(),
+                (0.065 + 0.042 * i) * self.canvas.image.height(),
+                fill="",
+                outline="",
+            )
+            self.rename_boxes += [temp]
+
+    # Keybind functions
+
     def handle_configure(self, event):
 
         """
-        Dynamically resizes the graph according to the window size
+        Dynamically resizes the graph and rename boxes according to the window size and name length
         """
 
         try:
@@ -463,7 +534,69 @@ class MainApplication(tk.Frame):
         except AttributeError:
             pass
 
-    # Keybing functions
+        temp = self.rename_boxes
+        self.rename_boxes = []
+        for i in range(len(self.DoseFigureHandler.plots)):
+            x = self.canvas.image.width()
+            y = self.canvas.image.height()
+            self.canvas.delete(temp[i])
+            self.rename_boxes += [
+                self.canvas.create_rectangle(
+                    (
+                        -0.00833
+                        * max(
+                            map(
+                                len,
+                                [
+                                    plot.filename
+                                    for plot in self.DoseFigureHandler.plots
+                                ],
+                            )
+                        )
+                        + 0.94633
+                    )
+                    * x,
+                    (0.023 + 0.042 * i) * y,
+                    0.988 * x,
+                    (0.065 + 0.042 * i) * y,
+                    fill="",
+                    outline="",
+                )
+            ]
+
+    def check_hand(self, e):
+        if e != None:
+            try:
+                hoverlist = []
+                for box in self.rename_boxes:
+                    bbox = self.canvas.bbox(box)
+                    if (
+                        bbox[0] < e.x
+                        and bbox[2] > e.x
+                        and bbox[1] < e.y
+                        and bbox[3] > e.y
+                    ):
+                        hoverlist += [True]
+                    else:
+                        hoverlist += [False]
+            except TypeError:
+                self.show_preview()
+
+            if True in hoverlist:
+                self.canvas.config(cursor="hand1")
+            else:
+                self.canvas.config(cursor="")
+
+    def check_click(self, e):
+        for index, box in enumerate(self.rename_boxes):
+            if e != None:
+                bbox = self.canvas.bbox(box)
+                if bbox[0] < e.x and bbox[2] > e.x and bbox[1] < e.y and bbox[3] > e.y:
+                    newname = sd.askstring("", self.text.changefilename[self.lang],)
+                    if newname != None:
+                        self.DoseFigureHandler.plots[index].filename = newname
+                        self.show_preview()
+
     def esc_key(self, event=None):
         self.close_file()
 
@@ -479,6 +612,9 @@ class MainApplication(tk.Frame):
     def z_key(self, event=None):
         self.remove_last_addition()
 
+    def p_key(self, event=None):
+        self.load_file("ptw")
+
     def s_key(self, event=None):
         self.save_graph()
 
